summaryrefslogtreecommitdiffstats
path: root/generic/tclInterp.c
diff options
context:
space:
mode:
authorandreas_kupries <akupries@shaw.ca>2008-07-21 19:37:35 (GMT)
committerandreas_kupries <akupries@shaw.ca>2008-07-21 19:37:35 (GMT)
commitc24d3516daee359922217e9267ba9e0e8aad1ce0 (patch)
treefafc8c6c64f4ad4f3c2dbb31b0e501a392f1f450 /generic/tclInterp.c
parent42ecaf98ac017a8cb5d769f57fd62677cc92ac4f (diff)
downloadtcl-c24d3516daee359922217e9267ba9e0e8aad1ce0.zip
tcl-c24d3516daee359922217e9267ba9e0e8aad1ce0.tar.gz
tcl-c24d3516daee359922217e9267ba9e0e8aad1ce0.tar.bz2
* generic/tclBasic.c: Extended the existing TIP #280 system (info
* generic/tclCmdAH.c: frame), added the ability to track the * generic/tclCompCmds.c: absolute location of literal procedure * generic/tclCompile.c: arguments, and making this information * generic/tclCompile.h: available to uplevel, eval, and * generic/tclInterp.c: siblings. This allows proper tracking of * generic/tclInt.h: absolute location through custom (Tcl-coded) * generic/tclNamesp.c: control structures based on uplevel, etc. * generic/tclProc.c:
Diffstat (limited to 'generic/tclInterp.c')
-rw-r--r--generic/tclInterp.c11
1 files changed, 7 insertions, 4 deletions
diff --git a/generic/tclInterp.c b/generic/tclInterp.c
index bd2db56..88438d7 100644
--- a/generic/tclInterp.c
+++ b/generic/tclInterp.c
@@ -9,7 +9,7 @@
* See the file "license.terms" for information on usage and redistribution
* of this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tclInterp.c,v 1.20.2.4 2008/01/30 10:46:56 msofer Exp $
+ * RCS: @(#) $Id: tclInterp.c,v 1.20.2.5 2008/07/21 19:37:43 andreas_kupries Exp $
*/
#include "tclInt.h"
@@ -2094,9 +2094,12 @@ SlaveEval(interp, slaveInterp, objc, objv)
#ifndef TCL_TIP280
result = Tcl_EvalObjEx(slaveInterp, objv[0], 0);
#else
- /* TIP #280 : Make invoker available to eval'd script */
- Interp* iPtr = (Interp*) interp;
- result = TclEvalObjEx(slaveInterp, objv[0], 0, iPtr->cmdFramePtr,0);
+ /* TIP #280 : Make actual argument location available to eval'd script */
+ Interp* iPtr = (Interp*) interp;
+ CmdFrame* invoker = iPtr->cmdFramePtr;
+ int word = 0;
+ TclArgumentGet (interp, objv[0], &invoker, &word);
+ result = TclEvalObjEx(slaveInterp, objv[0], 0, invoker, word);
#endif
} else {
objPtr = Tcl_ConcatObj(objc, objv);